%define libname_major 4
%define libname %mklibname rabbitmq %{libname_major}
%define develname %mklibname rabbitmq -d

Name:      librabbitmq
Summary:   Client library for AMQP
Version:   0.10.0
Release:   %mkrel 1
License:   MIT
Group:     System/Libraries
URL:       https://github.com/alanxz/rabbitmq-c
Source0:   https://github.com/alanxz/rabbitmq-c/archive/rabbitmq-c-%{version}.tar.gz
BuildRequires: cmake > 2.8
BuildRequires: pkgconfig(openssl)
# For tools
BuildRequires: pkgconfig(popt)
# For man page
BuildRequires: xmlto

%description
This is a C-language AMQP client library for use with AMQP servers
speaking protocol versions 0-9-1.

%package -n %libname
Summary:    Header files and development libraries for %{name}
Group:      System/Libraries

%description -n %libname
This package contains the header files and development libraries
for %{name}.

%package -n %develname
Summary:    Header files and development libraries for %{name}
Group:      Development/Other
Requires:   %libname = %{version}-%{release}

%description -n %develname
This package contains the header files and development libraries
for %{name}.

%package tools
Summary:    Example tools built using the librabbitmq package
Group:      Development/Other
Requires:   %libname = %{version}

%description tools
This package contains example tools built using %{name}.

It provides:
amqp-consume        Consume messages from a queue on an AMQP server
amqp-declare-queue  Declare a queue on an AMQP server
amqp-delete-queue   Delete a queue from an AMQP server
amqp-get            Get a message from a queue on an AMQP server
amqp-publish        Publish a message on an AMQP server

%prep
%setup -q -n rabbitmq-c-%{version}
%autopatch -p1

# Copy sources to be included in -devel docs.
cp -pr examples Examples

	
# This test requires a running server
sed -e '/test_basic/d' -i tests/CMakeLists.txt

%build
# static lib required for tests
%cmake \
  -DBUILD_TOOLS_DOCS:BOOL=ON \
  -DBUILD_STATIC_LIBS:BOOL=ON \
  -S .

%cmake_build

%install
%cmake_install

rm %{buildroot}%{_libdir}/librabbitmq.a

%check
: check .pc is usable
grep @ %{buildroot}%{_libdir}/pkgconfig/librabbitmq.pc && exit 1

: upstream tests
%ctest

%files -n %libname
%doc LICENSE-MIT
%{_libdir}/librabbitmq.so.%{libname_major}{,.*}

%files -n %develname
%doc AUTHORS THANKS TODO *.md
%doc Examples
%{_libdir}/librabbitmq.so
%{_includedir}/amqp*
%{_libdir}/pkgconfig/librabbitmq.pc

%files tools
%{_bindir}/amqp-*
%doc %{_mandir}/man1/amqp-*.1*
%doc %{_mandir}/man7/librabbitmq-tools.7*



%changelog
* Sat Aug 22 2020 guillomovitch <guillomovitch> 0.10.0-1.mga8
+ Revision: 1617946
- new version 0.10.0
+ neoclust <neoclust>
- Add P1 to fix CVE-2019-18609 (mga#25971)

* Thu Feb 13 2020 umeabot <umeabot> 0.8.0-6.mga8
+ Revision: 1514693
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sun Sep 23 2018 umeabot <umeabot> 0.8.0-5.mga7
+ Revision: 1299118
- Mageia 7 Mass Rebuild

* Sat Sep 09 2017 cjw <cjw> 0.8.0-4.mga7
+ Revision: 1152027
- rebuild for openssl 1.1
- patch0: fix use of strlen() without declaration

* Fri Jul 08 2016 neoclust <neoclust> 0.8.0-3.mga6
+ Revision: 1039831
- Fix groups
- Remove wrong require
- imported package librabbitmq


* Tue Apr 12 2016 Remi Collet <remi@fedoraproject.org> - 0.8.0-1
- update to 0.8.0

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Oct 13 2015 Remi Collet <remi@fedoraproject.org> - 0.7.1-1
- update to 0.7.1

* Fri Jul  3 2015 Remi Collet <remi@fedoraproject.org> - 0.7.0-1
- update to 0.7.0
- swicth to cmake
- switch from upstream tarball to github sources

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Apr 20 2015 Remi Collet <remi@fedoraproject.org> - 0.6.0-1
- update to 0.6.0
- soname changed to .4

* Mon Sep 15 2014 Remi Collet <remi@fedoraproject.org> - 0.5.2-1
- update to 0.5.2

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Wed Aug 13 2014 Remi Collet <remi@fedoraproject.org> - 0.5.1-1
- update to 0.5.1
- fix license handling
- move all documentation in devel subpackage

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue Apr 15 2014 Remi Collet <remi@fedoraproject.org> - 0.5.0-2
- upstream patch for missing function

* Mon Feb 17 2014 Remi Collet <remi@fedoraproject.org> - 0.5.0-1
- update to 0.5.0
- open https://github.com/alanxz/rabbitmq-c/issues/169 (version is 0.5.1-pre)
- open https://github.com/alanxz/rabbitmq-c/issues/170 (amqp_get_server_properties)

* Mon Jan 13 2014 Remi Collet <remi@fedoraproject.org> - 0.4.1-4
- drop BR python-simplejson

* Tue Jan  7 2014 Remi Collet <remi@fedoraproject.org> - 0.4.1-3
- fix broken librabbitmq.pc, #1039555
- add check for usable librabbitmq.pc

* Thu Jan  2 2014 Remi Collet <remi@fedoraproject.org> - 0.4.1-2
- fix Source0 URL

* Sat Sep 28 2013 Remi Collet <remi@fedoraproject.org> - 0.4.1-1
- update to 0.4.1
- add ssl support

* Thu Aug  1 2013 Remi Collet <remi@fedoraproject.org> - 0.3.0-3
- cleanups

* Wed Mar 13 2013 Remi Collet <remi@fedoraproject.org> - 0.3.0-2
- remove tools from main package

* Wed Mar 13 2013 Remi Collet <remi@fedoraproject.org> - 0.3.0-1
- update to 0.3.0
- create sub-package for tools

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-0.2.git2059570
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Aug 01 2012 Remi Collet <remi@fedoraproject.org> - 0.2-0.1.git2059570
- update to latest snapshot (version 0.2, moved to github)
- License is now MIT

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.1-0.3.hgfb6fca832fd2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sun Mar 11 2012 Remi Collet <remi@fedoraproject.org> - 0.1-0.2.hgfb6fca832fd2
- add %%check (per review comment)

* Sat Mar 10 2012 Remi Collet <remi@fedoraproject.org> - 0.1-0.1.hgfb6fca832fd2
- Initial RPM

